Function akka_projection_rs::consumer::run
source · pub async fn run<A, B, Envelope, EE, IH, SP>(
offset_store: Sender<Command>,
kill_switch: Receiver<()>,
source_provider: SP,
handler: IH
)where
A: Handler<Envelope = EE> + Send,
B: PendingHandler<Envelope = EE> + Send,
EE: TryFrom<Envelope>,
Envelope: WithPersistenceId + WithOffset + WithSeqNr + WithSource + Send,
IH: Into<Handlers<A, B>>,
SP: SourceProvider<Envelope = Envelope>,Expand description
Provides at-least-once projections with storage for projection offsets, meaning, for multiple runs of a projection, it is possible for events to repeat from previous runs.